@@ -61,7 +61,7 @@
 #define KPIPEWIRE_BUILD_DEPRECATED_SINCE(major, minor) 1
 
 #ifdef KPIPEWIRE_NO_DEPRECATED
-#  define KPIPEWIRE_DISABLE_DEPRECATED_BEFORE_AND_AT 0x51b08
+#  define KPIPEWIRE_DISABLE_DEPRECATED_BEFORE_AND_AT 0x60002
 #endif
 #ifdef KPIPEWIRE_NO_DEPRECATED_WARNINGS
 #  define KPIPEWIRE_DEPRECATED_WARNINGS_SINCE 0
@@ -71,12 +71,12 @@
 #  ifdef KPIPEWIRE_DISABLE_DEPRECATED_BEFORE_AND_AT
 #    define KPIPEWIRE_DEPRECATED_WARNINGS_SINCE KPIPEWIRE_DISABLE_DEPRECATED_BEFORE_AND_AT
 #  else
-#    define KPIPEWIRE_DEPRECATED_WARNINGS_SINCE 0x51b08
+#    define KPIPEWIRE_DEPRECATED_WARNINGS_SINCE 0x60002
 #  endif
 #endif
 
 #ifndef KPIPEWIRE_DISABLE_DEPRECATED_BEFORE_AND_AT
-#  define KPIPEWIRE_DISABLE_DEPRECATED_BEFORE_AND_AT 0x50000
+#  define KPIPEWIRE_DISABLE_DEPRECATED_BEFORE_AND_AT 0x60000
 #endif
 
 #ifdef KPIPEWIRE_DEPRECATED
